/*
 *  
 *  $Id: iconos.h 4511 2012-01-12 07:34:48Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include "ico_angulo.h"
#include "ico_anotacion.h"
#include "ico_cruz.h"
#include "ico_elevacion.h"
#include "ico_flecha.h"
#include "ico_longitud.h"
#include "ico_poligono.h"
#include "ico_varita.h"
#include "ico_lazo_chroma.h"
#include "ico_wl.h"
#include "ico_zoom.h"
#include "ico_slider.h"
#include "ico_pan.h"
#include "ico_lupa.h"
#include "ico_sin_opciones.h"
#include "ico_debug.h"
#include "ico_marcado.h"
#include "ico_rejilla.h"
#include "ico_mostrar_ocultar_tags.h"
#include "ico_desencajar.h"
#include "ico_corner_annotations.h"
#include "ico_informe.h"
#include "ico_mouse_r.h"
#include "ico_mouse_l.h"
#include "ico_mouse_rl.h"

